/*
 *                 IFS Research & Development
 *
 *  This program is protected by copyright law and by international
 *  conventions. All licensing, renting, lending or copying (including
 *  for private use), and all other use of the program, which is not
 *  expressively permitted by IFS Research & Development (IFS), is a
 *  violation of the rights of IFS. Such violations will be reported to the
 *  appropriate authorities.
 *
 *  VIOLATIONS OF ANY COPYRIGHT IS PUNISHABLE BY LAW AND CAN LEAD
 *  TO UP TO TWO YEARS OF IMPRISONMENT AND LIABILITY TO PAY DAMAGES.
 * ----------------------------------------------------------------------------
 * File        : MyAddressSenderConfig.java
 * Description :
 * Notes       :
 * ----------------------------------------------------------------------------
 * Modified    :
 *    2015-Aug-06  Jacek P  Created.
 * ----------------------------------------------------------------------------
 */

package ifs.fndint.connectsender;

import ifs.fnd.connect.senders.ConnectSender;
import ifs.fnd.connect.senders.addrcfg.AddressSenderConfig;

import java.io.File;

/**
 * Class defining configuration parameters for custom Connect Sender stored
 * on an address line. Parameters are read from address line and stored as read-only
 * (final) variables in the class for simple access. Therefore reading of
 * parameters is done by the inner Builder class.
 *
 * @author japase
 */
public class MyAddressSenderConfig extends AddressSenderConfig<MyConnectSenderConfig> {

    //==========================================================================
    //   Inner Builder class
    //==========================================================================

    public static class Builder extends AddressSenderConfig.Builder<MyConnectSenderConfig> {

        private transient String fileName = null;
        private transient File outDir;

        @Override
        protected void nativeInit() throws ConnectSender.PermanentFailureException {
            outDir = new File(config.outDir);

            // configuration data is typically stored in addressData field
            // which is available through the superclass. Additional parameters can be stored in
            // options that can be obtained using getOption() from the superclass.

            if (addressData == null) // addressData => file name
                throw new ConnectSender.PermanentFailureException("Output file name not defined.");

            fileName = ctx.replacePlaceholders(addressData);
        }

        @Override
        public AddressSenderConfig newConfig() {
            return new MyAddressSenderConfig(this);
        }
    }

    //==========================================================================
    //   Config instance
    //==========================================================================

    // Address specific config parameters public final variables
    public final transient String fileName;
    public final transient File outDir;

    private MyAddressSenderConfig(Builder builder) {
        super(builder);
        this.fileName = builder.fileName;
        this.outDir = builder.outDir;
    }
}