/*
 *                 IFS Research & Development
 *
 *  This program is protected by copyright law and by international
 *  conventions. All licensing, renting, lending or copying (including
 *  for private use), and all other use of the program, which is not
 *  expressively permitted by IFS Research & Development (IFS), is a
 *  violation of the rights of IFS. Such violations will be reported to the
 *  appropriate authorities.
 *
 *  VIOLATIONS OF ANY COPYRIGHT IS PUNISHABLE BY LAW AND CAN LEAD
 *  TO UP TO TWO YEARS OF IMPRISONMENT AND LIABILITY TO PAY DAMAGES.
 * ----------------------------------------------------------------------------
 * File        : MyConnectSender.java
 * Description :
 * Notes       :
 * ----------------------------------------------------------------------------
 * Modified    :
 *    2015-Aug-06  Jacek P  Created.
 * ----------------------------------------------------------------------------
 */

package ifs.fndint.connectsender;

//import dummy.MyLibrary;
import ifs.fnd.connect.senders.ConnectSender;
import ifs.fnd.util.IoUtil;
import ifs.fnd.util.Str;

import java.io.File;
import java.io.IOException;
import java.util.List;
import javax.activation.DataSource;

/**
 * Implementation of custom Connect Sender. This class is responsible for sending data
 * using the senders native protocol.
 *
 * @author japase
 */
public class MyConnectSender extends ConnectSender<MyConnectSenderConfig, MyAddressSenderConfig> {

    @Override
    protected byte[] nativeSend(List<DataSource> inputSources) throws SenderFailureException {
        byte[] inData = getMainInData(inputSources, 1);
        writeDataToFile(inData);

        // dummylig.jar contains just a single class dummy.MyLibrary
        // with one public method, dummyMethod(), returning String:
        // "Result from MyLibrary.dummyMethod()".
        // There is also a main() method calling the same public method.
//      MyLibrary dummyLib = new MyLibrary();
//      String dummyMsg = dummyLib.dummyMethod();
        String returnMessage = "File '" + addrCfg.fileName + "' has been created using ";
        if (log.debug) log.debug(returnMessage);
        return Str.getUtf8Bytes(returnMessage);
    }

    private void writeDataToFile(byte[] inData) throws TemporaryFailureException {
        try {
            File outFile = new File(addrCfg.outDir + File.separator + addrCfg.fileName);
            IoUtil.createParentDirectory(outFile);
            IoUtil.writeFile(outFile, inData);
        } catch (IOException e) {
            throw new TemporaryFailureException(e, "Error while sending data by MyConnectSender");
        }
    }
}
