/*
 *                 IFS Research & Development
 *
 *  This program is protected by copyright law and by international
 *  conventions. All licensing, renting, lending or copying (including
 *  for private use), and all other use of the program, which is not
 *  expressively permitted by IFS Research & Development (IFS), is a
 *  violation of the rights of IFS. Such violations will be reported to the
 *  appropriate authorities.
 *
 *  VIOLATIONS OF ANY COPYRIGHT IS PUNISHABLE BY LAW AND CAN LEAD
 *  TO UP TO TWO YEARS OF IMPRISONMENT AND LIABILITY TO PAY DAMAGES.
 * ----------------------------------------------------------------------------
 * File        : MyConnectSenderConfig.java
 * Description :
 * Notes       :
 * ----------------------------------------------------------------------------
 * Modified    :
 *    2015-Aug-06  Jacek P  Created.
 * ----------------------------------------------------------------------------
 */

package ifs.fndint.connectsender;

import ifs.fnd.base.IfsException;
import ifs.fnd.connect.config.Config;
import ifs.fnd.connect.config.ConnectorSendersConfig;
import ifs.fnd.connect.views.ConfigInstanceParam;

/**
 * Class defining configuration parameters for custom Connect Sender.
 * Parameters are read during system initialization and stored as read-only
 * (final) variables in the class for simple access. Therefore reading of
 * parameters is done by the inner Builder class.
 *
 * @author japase
 */
public class MyConnectSenderConfig extends ConnectorSendersConfig {

    //==========================================================================
    //   Inner Builder class
    //==========================================================================

    static class Builder extends ConnectorSendersConfig.Builder {

        private String outDir = null;

        @Override
        protected void init(String name, ConfigInstanceParam param) throws IfsException {
            // read all sender specific parameters
            // (FACTORY_CLASS, DEFAULT_INSTANCE, MAX_RETRIES, RETRY_INTERVAL and WORK_TIMEOUT
            // are handled by the framework and don't need to be read here)
            if ("OUT_DIRECTORY".equals(name)) {
                outDir = replacePlaceholders(getTextValue(name, param));
            }
        }

        @Override
        protected void postInit() throws IfsException {
            // any code that has to be executed after all parameters have been read,
            // e.g. parameter validation, consistency, variables that depend on several parameters, etc...
        }

        @Override
        protected Config newConfig() {
            return new MyConnectSenderConfig(this);
        }
    }

    //==========================================================================
    //   Config instance
    //==========================================================================

    // Sender specific config parameters as public final variables - have to be reread on config change
    // Following parameters common to all senders are handled by the superclasses
    // and ara available as public final variables:
    // instance, type, maxRetries, retryInterval, defaultInstance, workTimeout
    public final String outDir;

    private MyConnectSenderConfig(Builder builder) {
        super(builder);
        outDir = builder.outDir;
    }

    @Override
    public String toString() {
        return "MyConnectSenderConfig{" + "outDir=" + outDir + '}'
                + " + " + super.toString();
    }
}
